@@ -50,18 +50,20 @@ class AgentInstanceModel::Private
 
 void AgentInstanceModel::Private::instanceAdded( const AgentInstance &instance )
 {
-  emit mParent->layoutAboutToBeChanged();
+  mParent->beginInsertRows( QModelIndex(), mInstances.count(), mInstances.count() );
   mInstances.append( instance );
-
-  emit mParent->layoutChanged();
+  mParent->endInsertRows();
 }
 
 void AgentInstanceModel::Private::instanceRemoved( const AgentInstance &instance )
 {
-  emit mParent->layoutAboutToBeChanged();
-  mInstances.removeAll( instance );
+  const int index = mInstances.indexOf( instance );
+  if ( index == -1 )
+    return;
 
-  emit mParent->layoutChanged();
+  mParent->beginRemoveRows( QModelIndex(), index, index );
+  mInstances.removeAll( instance );
+  mParent->endRemoveRows();
 }
 
 void AgentInstanceModel::Private::instanceChanged( const AgentInstance &instance )
@@ -84,6 +86,13 @@ AgentInstanceModel::AgentInstanceModel( QObject *parent )
 {
   d->mInstances = AgentManager::self()->instances();
 
+  QHash<int, QByteArray> roles = roleNames();
+  roles.insert( StatusRole, "status" );
+  roles.insert( StatusMessageRole, "statusMessage" );
+  roles.insert( ProgressRole, "progress" );
+  roles.insert( OnlineRole, "online" );
+  setRoleNames( roles );
+
   connect( AgentManager::self(), SIGNAL( instanceAdded( const Akonadi::AgentInstance& ) ),
            this, SLOT( instanceAdded( const Akonadi::AgentInstance& ) ) );
   connect( AgentManager::self(), SIGNAL( instanceRemoved( const Akonadi::AgentInstance& ) ),
