@@ -19,6 +19,8 @@
 
 #include "agenttypewidget.h"
 
+#include <KDebug>
+
 #include <QtGui/QApplication>
 #include <QtGui/QHBoxLayout>
 #include <QtGui/QListView>
@@ -28,7 +30,8 @@
 #include "agenttype.h"
 #include "agenttypemodel.h"
 
-using namespace Akonadi;
+namespace Akonadi {
+namespace Internal {
 
 /**
  * @internal
@@ -45,6 +48,10 @@ class AgentTypeWidgetDelegate : public QAbstractItemDelegate
     void drawFocus( QPainter*, const QStyleOptionViewItem&, const QRect& ) const;
 };
 
+}
+
+using Akonadi::Internal::AgentTypeWidgetDelegate;
+
 
 /**
  * @internal
@@ -59,6 +66,12 @@ class AgentTypeWidget::Private
 
     void currentAgentTypeChanged( const QModelIndex&, const QModelIndex& );
 
+    void typeActivated( const QModelIndex &index )
+    {
+      if ( index.flags() & (Qt::ItemIsSelectable | Qt::ItemIsEnabled) )
+        emit mParent->activated();
+    }
+
     AgentTypeWidget *mParent;
     QListView *mView;
     AgentTypeModel *mModel;
@@ -83,10 +96,11 @@ AgentTypeWidget::AgentTypeWidget( QWidget *parent )
 {
   QHBoxLayout *layout = new QHBoxLayout( this );
   layout->setMargin( 0 );
-  layout->setSpacing( 0 );
 
   d->mView = new QListView( this );
   d->mView->setItemDelegate( new AgentTypeWidgetDelegate( d->mView ) );
+  d->mView->setVerticalScrollMode( QAbstractItemView::ScrollPerPixel );
+  d->mView->setAlternatingRowColors( true );
   layout->addWidget( d->mView );
 
   d->mModel = new AgentTypeModel( d->mView );
@@ -100,7 +114,7 @@ AgentTypeWidget::AgentTypeWidget( QWidget *parent )
   connect( d->mView->selectionModel(), SIGNAL( currentChanged( const QModelIndex&, const QModelIndex& ) ),
            this, SLOT( currentAgentTypeChanged( const QModelIndex&, const QModelIndex& ) ) );
   connect( d->mView, SIGNAL( activated( const QModelIndex& ) ),
-           SIGNAL( activated() ) );
+           SLOT( typeActivated(QModelIndex) ) );
 }
 
 AgentTypeWidget::~AgentTypeWidget()
@@ -165,13 +179,16 @@ void AgentTypeWidgetDelegate::paint( QPainter *painter, const QStyleOptionViewIt
   int wc = fm.boundingRect( 0, 0, 0, 0, Qt::AlignLeft, comment ).width();
   int wp = pixmap.width();
 
+  QStyleOptionViewItemV4 opt(option);
+  opt.showDecorationSelected = true;
+  QApplication::style()->drawPrimitive( QStyle::PE_PanelItemViewItem, &opt, painter );
+
   QPen pen = painter->pen();
   QPalette::ColorGroup cg = option.state & QStyle::State_Enabled
                             ? QPalette::Normal : QPalette::Disabled;
   if (cg == QPalette::Normal && !(option.state & QStyle::State_Active))
     cg = QPalette::Inactive;
   if (option.state & QStyle::State_Selected) {
-    painter->fillRect(option.rect, option.palette.brush(cg, QPalette::Highlight));
     painter->setPen(option.palette.color(cg, QPalette::HighlightedText));
   } else {
     painter->setPen(option.palette.color(cg, QPalette::Text));
@@ -243,4 +260,6 @@ void AgentTypeWidgetDelegate::drawFocus( QPainter *painter, const QStyleOptionVi
   }
 }
 
+}
+
 #include "agenttypewidget.moc"
