@@ -235,6 +235,13 @@ class AKONADI_EXPORT Collection : public Entity
      */
     KUrl url() const;
 
+    /**
+     * Returns whether the collection is virtual, for example a search collection.
+     *
+     * @since 4.6
+     */
+    bool isVirtual() const;
+
   private:
     AKONADI_DECLARE_PRIVATE( Collection )
     friend class CollectionFetchJob;
