@@ -115,6 +115,8 @@ void EntityTreeModelPrivate::init( ChangeRecorder *monitor )
               SLOT( monitoredMimeTypeChanged( const QString&, bool ) ) );
   q->connect( monitor, SIGNAL( collectionMonitored(Akonadi::Collection,bool)),
               SLOT( monitoredCollectionsChanged( const Akonadi::Collection&, bool ) ) );
+  q->connect( monitor, SIGNAL( resourceMonitored(QByteArray,bool)),
+              SLOT( monitoredResourcesChanged( const QByteArray&, bool ) ) );
 
   // monitor collection changes
   q->connect( monitor, SIGNAL( collectionChanged( const Akonadi::Collection& ) ),
@@ -518,6 +520,14 @@ void EntityTreeModelPrivate::monitoredCollectionsChanged( const Akonadi::Collect
   endResetModel();
 }
 
+void EntityTreeModelPrivate::monitoredResourcesChanged(const QByteArray& resource, bool monitored)
+{
+  Q_UNUSED(resource)
+  Q_UNUSED(monitored)
+  beginResetModel();
+  endResetModel();
+}
+
 void EntityTreeModelPrivate::retrieveAncestors( const Akonadi::Collection& collection )
 {
   Q_Q( EntityTreeModel );
