@@ -23,57 +23,42 @@
 #include "item.h"
 #include "job_p.h"
 #include "protocolhelper_p.h"
+#include <akonadi/private/imapparser_p.h>
+#include "movejobimpl_p.h"
 
 using namespace Akonadi;
 
-class Akonadi::ItemMoveJobPrivate: public JobPrivate
+class Akonadi::ItemMoveJobPrivate: public MoveJobImpl<Item, ItemMoveJob>
 {
   public:
-    ItemMoveJobPrivate( ItemMoveJob *parent )
-      : JobPrivate( parent )
-    {
-    }
-
-    Collection mTarget;
-    Item::List mItems;
+    ItemMoveJobPrivate( ItemMoveJob *parent ) : MoveJobImpl<Item, ItemMoveJob>( parent ) {}
+    Q_DECLARE_PUBLIC( ItemMoveJob )
 };
 
-ItemMoveJob::ItemMoveJob(const Item & item, const Collection & target, QObject * parent) :
+ItemMoveJob::ItemMoveJob(const Item &item, const Collection &destination, QObject *parent) :
     Job( new ItemMoveJobPrivate( this ), parent )
 {
   Q_D( ItemMoveJob );
-  d->mTarget = target;
-  d->mItems << item;
+  d->destination = destination;
+  d->objectsToMove.append( item );
 }
 
-ItemMoveJob::ItemMoveJob( const Item::List& items, const Collection& target, QObject* parent) :
+ItemMoveJob::ItemMoveJob( const Item::List &items, const Collection &destination, QObject* parent) :
   Job( new ItemMoveJobPrivate( this ), parent )
 {
   Q_D( ItemMoveJob );
-  d->mTarget = target;
-  d->mItems = items;
+  d->destination = destination;
+  d->objectsToMove = items;
 }
 
-ItemMoveJob::~ ItemMoveJob()
+ItemMoveJob::~ItemMoveJob()
 {
 }
 
 void ItemMoveJob::doStart()
 {
   Q_D( ItemMoveJob );
-  QByteArray command = d->newTag();
-  try {
-    command += ProtocolHelper::itemSetToByteArray( d->mItems, "MOVE" );
-  } catch ( const std::exception &e ) {
-    setError( Unknown );
-    setErrorText( QString::fromUtf8( e.what() ) );
-    emitResult();
-    return;
-  }
-  command += ' ';
-  command += QByteArray::number( d->mTarget.id() );
-  command += '\n';
-  d->writeData( command );
+  d->sendCommand( "MOVE" );
 }
 
 #include "itemmovejob.moc"
