@@ -35,10 +35,12 @@
 #include <QtCore/QQueue>
 #include <QtCore/QThreadStorage>
 #include <QtCore/QTimer>
+#include <QtCore/QThread>
 #include <QSettings>
 
 #include <QtNetwork/QLocalSocket>
 #include <QtNetwork/QTcpSocket>
+#include <QtNetwork/QHostAddress>
 
 // ### FIXME pipelining got broken by switching result emission in JobPrivate::handleResponse to delayed emission
 // in order to work around exec() deadlocks. As a result of that Session knows to late about a finished job and still
@@ -121,6 +123,9 @@ void SessionPrivate::reconnect()
     serverAddress = connectionSettings.value( QLatin1String( "Data/UnixPath" ), defaultSocketDir + QLatin1String( "/akonadiserver.socket" ) ).toString();
 #endif
   }
+#ifdef Q_OS_WINCE
+  useTcp = true;
+#endif
 
   // create sockets if not yet done, note that this does not yet allow changing socket types on the fly
   // but that's probably not something we need to support anyway
@@ -138,11 +143,17 @@ void SessionPrivate::reconnect()
 
   // actually do connect
   kDebug() << "connectToServer" << serverAddress;
+#ifdef Q_OS_WINCE
+    tcpSocket->connectToHost( QHostAddress::LocalHost, 31414 );
+#else
   if ( !useTcp ) {
     localSocket->connectToServer( serverAddress );
   } else {
     tcpSocket->connectToHost( serverAddress, port );
   }
+#endif
+
+  emit mParent->reconnected();
 }
 
 void SessionPrivate::socketError( QLocalSocket::LocalSocketError )
@@ -324,6 +335,14 @@ void SessionPrivate::serverStateChanged( ServerManager::State state )
     reconnect();
 }
 
+void SessionPrivate::itemRevisionChanged( Akonadi::Item::Id itemId, int oldRevision, int newRevision )
+{
+  // only deal with the queue, for the guys in the pipeline it's too late already anyway
+  // and they shouldn't have gotten there if they depend on a preceeding job anyway.
+  foreach ( Job *job, queue )
+    job->d_ptr->updateItemRevision( itemId, oldRevision, newRevision );
+}
+
 //@endcond
 
 
@@ -381,7 +400,7 @@ QByteArray Session::sessionId() const
   return d->sessionId;
 }
 
-QThreadStorage<Session*> instances;
+static QThreadStorage<Session*> instances;
 
 void SessionPrivate::createDefaultSession( const QByteArray &sessionId )
 {
@@ -413,7 +432,7 @@ void Session::clear()
   d->jobRunning = false;
   d->connected = false;
   if ( d->socket )
-    d->socket->disconnect( this ); // prevent signal emitted from close() causing mayhem - we might be called from ~QThreadStorage!
+      d->socket->disconnect( this ); // prevent signal emitted from close() causing mayhem - we might be called from ~QThreadStorage!
   delete d->socket;
   d->socket = 0;
   QMetaObject::invokeMethod( this, "reconnect", Qt::QueuedConnection ); // avoids reconnecting in the dtor
