@@ -428,7 +428,9 @@ void SessionPrivate::stopSocketTimer()
 
 void SessionPrivate::restartSocketTimer()
 {
-  stopSocketTimer();
+  if ( socketTimer.isActive() ) {
+    stopSocketTimer();
+  }
   startSocketTimer();
 }
 
