@@ -1,7 +1,7 @@
 /*  -*- c++ -*-
     kmime_codec_qp.cpp
 
-    KMime, the KDE internet mail/usenet news message library.
+    KMime, the KDE Internet mail/usenet news message library.
     Copyright (c) 2002 Marc Mutz <mutz@kde.org>
 
     This library is free software; you can redistribute it and/or
@@ -418,8 +418,8 @@ bool QuotedPrintableDecoder::decode( const char* &scursor,
       } else if ( ch == '\r' ) {
         mExpectLF = true;
       } else {
-        kWarning() << "QuotedPrintableDecoder:" << ch <<
-          "illegal character in input stream!";
+        //kWarning() << "QuotedPrintableDecoder:" << ch <<
+        //  "illegal character in input stream!";
         *dcursor++ = char( ch );
       }
     }
@@ -670,7 +670,7 @@ bool Rfc2047QEncodingEncoder::encode( const char* &scursor,
   }
 
   while ( scursor != send && dcursor != dend ) {
-    uchar value;
+    uchar value = 0;
     switch ( mStepNo ) {
     case 0:
       // read the next char and decide if and how do encode:
@@ -715,7 +715,7 @@ bool Rfc2047QEncodingEncoder::finish( char* &dcursor, const char * const dend )
 
   // write the last bits of mAccu, if any:
   while ( mStepNo != 0 && dcursor != dend ) {
-    uchar value;
+    uchar value = 0;
     switch ( mStepNo ) {
     case 1:
       // extract hi-nibble:
