@@ -36,6 +36,7 @@
 
 #include "kmime_content.h"
 #include "kmime_content_p.h"
+#include "kmime_codecs.h"
 #include "kmime_message.h"
 #include "kmime_header_parsing.h"
 #include "kmime_header_parsing_p.h"
@@ -132,22 +133,7 @@ void Content::setContent( const QList<QByteArray> &l )
 void Content::setContent( const QByteArray &s )
 {
   Q_D(Content);
-  d->head.clear();
-  d->body.clear();
-
-  // empty header
-  if ( s.startsWith( '\n' ) ) {
-    d->body = s.right( s.length() - 1 );
-    return;
-  }
-
-  int pos = s.indexOf( "\n\n", 0 );
-  if ( pos > -1 ) {
-    d->head = s.left( ++pos );  //header *must* end with "\n" !!
-    d->body = s.mid( pos + 1, s.length() - pos - 1 );
-  } else {
-    d->head = s;
-  }
+  KMime::HeaderParsing::extractHeaderAndBody( s, d->head, d->body );
 }
 
 QByteArray Content::head() const
@@ -178,6 +164,7 @@ void Content::parse()
 
   // Clean up old headers and parse them again.
   qDeleteAll( h_eaders );
+  h_eaders.clear();
   h_eaders = HeaderParsing::parseHeaders( d->head );
   foreach( Headers::Base *h, h_eaders ) {
     h->setParent( this );
@@ -294,7 +281,19 @@ QByteArray Content::encodedContent( bool useCrLf )
   // Head.
   e = d->head;
   e += '\n';
+  e += encodedBody();
 
+  if ( useCrLf ) {
+    return LFtoCRLF( e );
+  } else {
+    return e;
+  }
+}
+
+QByteArray Content::encodedBody()
+{
+  Q_D( Content );
+  QByteArray e;
   // Body.
   if( d->frozen ) {
     // This Content is frozen.
@@ -331,6 +330,9 @@ QByteArray Content::encodedContent( bool useCrLf )
     Headers::ContentType *ct=contentType();
     QByteArray boundary = "\n--" + ct->boundary();
 
+    if ( !d->preamble.isEmpty() )
+      e += d->preamble;
+
     //add all (encoded) contents separated by boundaries
     foreach ( Content *c, d->multipartContents ) {
       e+=boundary + '\n';
@@ -338,50 +340,53 @@ QByteArray Content::encodedContent( bool useCrLf )
     }
     //finally append the closing boundary
     e += boundary+"--\n";
-  };
 
-  if ( useCrLf ) {
-    return LFtoCRLF( e );
-  } else {
-    return e;
-  }
+    if ( !d->epilogue.isEmpty() )
+      e += d->epilogue;
+  };
+  return e;
 }
 
 QByteArray Content::decodedContent()
 {
-  QByteArray temp, ret;
+  QByteArray ret;
   Headers::ContentTransferEncoding *ec=contentTransferEncoding();
   bool removeTrailingNewline=false;
-  int size = d_ptr->body.length();
 
-  if ( size == 0 ) {
+  if ( d_ptr->body.length() == 0 ) {
     return ret;
   }
 
-  temp.resize( size );
-  memcpy( temp.data(), d_ptr->body.data(), size );
-
   if ( ec->decoded() ) {
-    ret = temp;
+    ret = d_ptr->body;
     removeTrailingNewline = true;
   } else {
     switch( ec->encoding() ) {
     case Headers::CEbase64 :
-      KCodecs::base64Decode( temp, ret );
+    {
+      KMime::Codec *codec = KMime::Codec::codecForName( "base64" );
+      Q_ASSERT( codec );
+      ret.resize( codec->maxDecodedSizeFor( d_ptr->body.size() ) );
+      KMime::Decoder* decoder = codec->makeDecoder();
+      QByteArray::const_iterator inputIt = d_ptr->body.constBegin();
+      QByteArray::iterator resultIt = ret.begin();
+      decoder->decode( inputIt, d_ptr->body.constEnd(), resultIt, ret.end() );
+      ret.truncate( resultIt - ret.begin() );
       break;
+    }
     case Headers::CEquPr :
       ret = KCodecs::quotedPrintableDecode( d_ptr->body );
       removeTrailingNewline = true;
       break;
     case Headers::CEuuenc :
-      KCodecs::uudecode( temp, ret );
+      KCodecs::uudecode( d_ptr->body, ret );
       break;
     case Headers::CEbinary :
-      ret = temp;
+      ret = d_ptr->body;
       removeTrailingNewline = false;
       break;
     default :
-      ret = temp;
+      ret = d_ptr->body;
       removeTrailingNewline = true;
     }
   }
@@ -401,7 +406,7 @@ QString Content::decodedText( bool trimText, bool removeTrailingNewlines )
 
   bool ok = true;
   QTextCodec *codec =
-    KGlobal::charsets()->codecForName( contentType()->charset(), ok );
+    KGlobal::charsets()->codecForName( QLatin1String( contentType()->charset() ), ok );
 
   QString s = codec->toUnicode( d_ptr->body.data(), d_ptr->body.length() );
 
@@ -414,14 +419,14 @@ QString Content::decodedText( bool trimText, bool removeTrailingNewlines )
         }
       }
       else {
-        if ( s[i] != '\n' ) {
+        if ( s[i] != QLatin1Char( '\n' ) ) {
           break;
         }
       }
     }
     s.truncate( i + 1 );
   } else {
-    if ( s.right( 1 ) == "\n" ) {
+    if ( s.right( 1 ) == QLatin1String( "\n" ) ) {
       s.truncate( s.length() - 1 ); // remove trailing new-line
     }
   }
@@ -433,7 +438,7 @@ void Content::fromUnicodeString( const QString &s )
 {
   bool ok = true;
   QTextCodec *codec =
-    KGlobal::charsets()->codecForName( contentType()->charset(), ok );
+    KGlobal::charsets()->codecForName( QLatin1String( contentType()->charset() ), ok );
 
   if ( !ok ) { // no suitable codec found => try local settings and hope the best ;-)
     codec = KGlobal::locale()->codecForEncoding();
@@ -1021,11 +1026,11 @@ bool ContentPrivate::parseUuencoded()
     for( int i = 0; i < uup.binaryParts().count(); ++i ) {
       Content *c = new Content( q );
       c->contentType()->setMimeType( uup.mimeTypes().at( i ) );
-      c->contentType()->setName( uup.filenames().at( i ), QByteArray( /*charset*/ ) );
+      c->contentType()->setName( QLatin1String( uup.filenames().at( i ) ), QByteArray( /*charset*/ ) );
       c->contentTransferEncoding()->setEncoding( Headers::CEuuenc );
       c->contentTransferEncoding()->setDecoded( false );
       c->contentDisposition()->setDisposition( Headers::CDattachment );
-      c->contentDisposition()->setFilename( uup.filenames().at( i ) );
+      c->contentDisposition()->setFilename( QLatin1String( uup.filenames().at( i ) ) );
       c->setBody( uup.binaryParts().at( i ) );
       c->changeEncoding( Headers::CEbase64 ); // Convert to base64.
       multipartContents.append( c );
@@ -1075,10 +1080,10 @@ bool ContentPrivate::parseYenc()
     for ( int i=0; i<yenc.binaryParts().count(); i++ ) {
       Content *c = new Content( q );
       c->contentType()->setMimeType( yenc.mimeTypes().at( i ) );
-      c->contentType()->setName( yenc.filenames().at( i ), QByteArray( /*charset*/ ) );
+      c->contentType()->setName( QLatin1String( yenc.filenames().at( i ) ), QByteArray( /*charset*/ ) );
       c->contentTransferEncoding()->setEncoding( Headers::CEbinary );
       c->contentDisposition()->setDisposition( Headers::CDattachment );
-      c->contentDisposition()->setFilename( yenc.filenames().at( i ) );
+      c->contentDisposition()->setFilename( QLatin1String( yenc.filenames().at( i ) ) );
       c->setBody( yenc.binaryParts().at( i ) ); // Yenc bodies are binary.
       c->changeEncoding( Headers::CEbase64 ); // Convert to base64.
       multipartContents.append( c );
@@ -1100,7 +1105,10 @@ bool ContentPrivate::parseMultipart()
   if( !mpp.parse() ) {
     return false; // Parsing failed.
   }
-   
+
+  preamble = mpp.preamble();
+  epilogue = mpp.epilouge();
+
   // Determine the category of the subparts (used in attachments()).
   Headers::contentCategory cat;
   if( ct->isSubtype( "alternative" ) ) {
