@@ -179,6 +179,9 @@ class KMIME_EXPORT Content
       parse() if you want to access individual headers, sub-Contents or the
       encapsulated message.
 
+      @note The passed data must not contain any CRLF sequences, only LF.
+            Use CRLFtoLF for conversion before passing in the data.
+
       @param s is a QByteArray containing the raw Content data.
     */
     void setContent( const QByteArray &s );
@@ -479,6 +482,14 @@ class KMIME_EXPORT Content
     */
     QByteArray encodedContent( bool useCrLf = false );
 
+    /**
+     * Like encodedContent(), with the difference that only the body will be returned, i.e. the
+     * headers are excluded.
+     *
+     * @since 4.6
+     */
+    QByteArray encodedBody();
+
     /**
      * Returns the decoded Content body.
      *
