@@ -27,6 +27,7 @@ static const char configKeyDefaultIdentity[] = "Default Identity";
 
 #include <kemailsettings.h> // for IdentityEntry::fromControlCenter()
 #include <klocale.h>
+#include <kglobal.h>
 #include <kdebug.h>
 #include <kconfig.h>
 #include <kuser.h>
@@ -59,12 +60,14 @@ IdentityManager::IdentityManager( bool readonly, QObject *parent,
     : QObject( parent )
 {
   setObjectName( name );
+  KGlobal::locale()->insertCatalog("libkpimidentities");
   new IdentityManagerAdaptor( this );
   QDBusConnection dbus = QDBusConnection::sessionBus();
   const QString dbusPath = newDBusObjectName();
+  setProperty( "uniqueDBusPath", dbusPath );
   const QString dbusInterface = "org.kde.pim.IdentityManager";
   dbus.registerObject( dbusPath, this );
-  dbus.connect( QString(), dbusPath, dbusInterface, "identitiesChanged", this,
+  dbus.connect( QString(), QString(), dbusInterface, "identitiesChanged", this,
                 SLOT( slotIdentitiesChanged( QString ) ) );
 
   mReadOnly = readonly;
@@ -170,7 +173,9 @@ void IdentityManager::commit()
   emit changed(); // normal signal
 
   // DBus signal for other IdentityManager instances
-  emit identitiesChanged( QDBusConnection::sessionBus().baseService() );
+  const QString ourIdentifier = QString::fromLatin1( "%1/%2" ).arg( QDBusConnection::sessionBus().baseService() )
+                                                              .arg( property( "uniqueDBusPath" ).toString() );
+  emit identitiesChanged( ourIdentifier );
 }
 
 void IdentityManager::rollback()
@@ -225,7 +230,7 @@ void IdentityManager::writeConfig() const
       // Also write the default identity to emailsettings
       KEMailSettings es;
       es.setSetting( KEMailSettings::RealName, (*it).fullName() );
-      es.setSetting( KEMailSettings::EmailAddress, (*it).emailAddr() );
+      es.setSetting( KEMailSettings::EmailAddress, (*it).primaryEmailAddress() );
       es.setSetting( KEMailSettings::Organization, (*it).organization() );
       es.setSetting( KEMailSettings::ReplyToAddress, (*it).replyToAddr() );
     }
@@ -315,13 +320,13 @@ const Identity &IdentityManager::identityForUoidOrDefault( uint uoid ) const
 const Identity &IdentityManager::identityForAddress(
   const QString &addresses ) const
 {
-  QStringList addressList = KPIMUtils::splitAddressList( addresses );
-  for ( ConstIterator it = begin(); it != end(); ++it ) {
-    for ( QStringList::ConstIterator addrIt = addressList.constBegin();
-          addrIt != addressList.constEnd(); ++addrIt ) {
-      if ( (*it).emailAddr().toLower() == KPIMUtils::extractEmailAddress( *addrIt ).toLower() ) {
-        return (*it);
-      }
+  const QStringList addressList = KPIMUtils::splitAddressList( addresses );
+  foreach ( const QString &fullAddress, addressList ) {
+    const QString addrSpec = KPIMUtils::extractEmailAddress( fullAddress ).toLower();
+    for ( ConstIterator it = begin(); it != end(); ++it ) {
+      const Identity &identity = *it;
+      if ( identity.matchesEmailAddress( addrSpec ) )
+        return identity;
     }
   }
   return Identity::null();
@@ -418,6 +423,21 @@ bool IdentityManager::removeIdentity( const QString &name )
   return false;
 }
 
+bool IdentityManager::removeIdentityForced( const QString &name )
+{
+  for ( Iterator it = modifyBegin(); it != modifyEnd(); ++it ) {
+    if ( (*it).identityName() == name ) {
+      bool removedWasDefault = (*it).isDefault();
+      mShadowIdentities.erase( it );
+      if ( removedWasDefault && !mShadowIdentities.isEmpty() ) {
+        mShadowIdentities.first().setIsDefault( true );
+      }
+      return true;
+    }
+  }
+  return false;
+}
+
 Identity &IdentityManager::newFromScratch( const QString &name )
 {
   return newFromExisting( Identity( name ) );
@@ -554,7 +574,9 @@ QStringList KPIMIdentities::IdentityManager::allEmails() const
 {
   QStringList lst;
   for ( ConstIterator it = begin(); it != end(); ++it ) {
-    lst << (*it).emailAddr();
+    lst << (*it).primaryEmailAddress();
+    if ( !(*it).emailAliases().isEmpty() )
+      lst << (*it).emailAliases();
   }
   return lst;
 }
@@ -567,7 +589,9 @@ void KPIMIdentities::IdentityManager::slotRollback()
 void KPIMIdentities::IdentityManager::slotIdentitiesChanged( const QString &id )
 {
   kDebug( 5325 ) <<" KPIMIdentities::IdentityManager::slotIdentitiesChanged :" << id;
-  if ( id != QDBusConnection::sessionBus().baseService() ) {
+  const QString ourIdentifier = QString::fromLatin1( "%1/%2" ).arg( QDBusConnection::sessionBus().baseService() )
+                                                              .arg( property( "uniqueDBusPath" ).toString() );
+  if ( id != ourIdentifier ) {
     mConfig->reparseConfiguration();
     Q_ASSERT( !hasPendingChanges() );
     readConfig( mConfig );
